# ory-kratos-client
Welcome to the ORY Kratos HTTP API documentation!

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: latest
- Package version: v0.2.0-alpha.2
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/ory/sdk.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/ory/sdk.git`)

Then import the package:
```python
import ory_kratos_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import ory_kratos_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import ory_kratos_client
from ory_kratos_client.rest import ApiException
from pprint import pprint


# Defining host is optional and default to http://localhost
configuration.host = "http://localhost"
# Enter a context with an instance of the API client
with ory_kratos_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = ory_kratos_client.AdminApi(api_client)
    body = ory_kratos_client.Identity() # Identity | 

    try:
        # Create an identity
        api_response = api_instance.create_identity(body)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AdminApi->create_identity: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AdminApi* | [**create_identity**](docs/AdminApi.md#create_identity) | **POST** /identities | Create an identity
*AdminApi* | [**delete_identity**](docs/AdminApi.md#delete_identity) | **DELETE** /identities/{id} | Delete an identity
*AdminApi* | [**get_identity**](docs/AdminApi.md#get_identity) | **GET** /identities/{id} | Get an identity
*AdminApi* | [**get_schema**](docs/AdminApi.md#get_schema) | **GET** /schemas/{id} | 
*AdminApi* | [**get_self_service_browser_login_request**](docs/AdminApi.md#get_self_service_browser_login_request) | **GET** /self-service/browser/flows/requests/login | Get the request context of browser-based login user flows
*AdminApi* | [**get_self_service_browser_registration_request**](docs/AdminApi.md#get_self_service_browser_registration_request) | **GET** /self-service/browser/flows/requests/registration | Get the request context of browser-based registration user flows
*AdminApi* | [**get_self_service_browser_settings_request**](docs/AdminApi.md#get_self_service_browser_settings_request) | **GET** /self-service/browser/flows/requests/settings | Get the request context of browser-based settings flows
*AdminApi* | [**get_self_service_error**](docs/AdminApi.md#get_self_service_error) | **GET** /self-service/errors | Get user-facing self-service errors
*AdminApi* | [**get_self_service_verification_request**](docs/AdminApi.md#get_self_service_verification_request) | **GET** /self-service/browser/flows/requests/verification | Get the request context of browser-based verification flows
*AdminApi* | [**list_identities**](docs/AdminApi.md#list_identities) | **GET** /identities | List all identities in the system
*AdminApi* | [**update_identity**](docs/AdminApi.md#update_identity) | **PUT** /identities/{id} | Update an identity
*CommonApi* | [**get_schema**](docs/CommonApi.md#get_schema) | **GET** /schemas/{id} | 
*CommonApi* | [**get_self_service_browser_login_request**](docs/CommonApi.md#get_self_service_browser_login_request) | **GET** /self-service/browser/flows/requests/login | Get the request context of browser-based login user flows
*CommonApi* | [**get_self_service_browser_registration_request**](docs/CommonApi.md#get_self_service_browser_registration_request) | **GET** /self-service/browser/flows/requests/registration | Get the request context of browser-based registration user flows
*CommonApi* | [**get_self_service_browser_settings_request**](docs/CommonApi.md#get_self_service_browser_settings_request) | **GET** /self-service/browser/flows/requests/settings | Get the request context of browser-based settings flows
*CommonApi* | [**get_self_service_error**](docs/CommonApi.md#get_self_service_error) | **GET** /self-service/errors | Get user-facing self-service errors
*CommonApi* | [**get_self_service_verification_request**](docs/CommonApi.md#get_self_service_verification_request) | **GET** /self-service/browser/flows/requests/verification | Get the request context of browser-based verification flows
*HealthApi* | [**is_instance_alive**](docs/HealthApi.md#is_instance_alive) | **GET** /health/alive | Check alive status
*HealthApi* | [**is_instance_ready**](docs/HealthApi.md#is_instance_ready) | **GET** /health/ready | Check readiness status
*PublicApi* | [**complete_self_service_browser_settings_password_strategy_flow**](docs/PublicApi.md#complete_self_service_browser_settings_password_strategy_flow) | **POST** /self-service/browser/flows/settings/strategies/password | Complete the browser-based settings flow for the password strategy
*PublicApi* | [**complete_self_service_browser_settings_profile_strategy_flow**](docs/PublicApi.md#complete_self_service_browser_settings_profile_strategy_flow) | **POST** /self-service/browser/flows/settings/strategies/profile | Complete the browser-based settings flow for profile data
*PublicApi* | [**complete_self_service_browser_verification_flow**](docs/PublicApi.md#complete_self_service_browser_verification_flow) | **POST** /self-service/browser/flows/verification/{via}/complete | Complete the browser-based verification flows
*PublicApi* | [**get_schema**](docs/PublicApi.md#get_schema) | **GET** /schemas/{id} | 
*PublicApi* | [**get_self_service_browser_login_request**](docs/PublicApi.md#get_self_service_browser_login_request) | **GET** /self-service/browser/flows/requests/login | Get the request context of browser-based login user flows
*PublicApi* | [**get_self_service_browser_registration_request**](docs/PublicApi.md#get_self_service_browser_registration_request) | **GET** /self-service/browser/flows/requests/registration | Get the request context of browser-based registration user flows
*PublicApi* | [**get_self_service_browser_settings_request**](docs/PublicApi.md#get_self_service_browser_settings_request) | **GET** /self-service/browser/flows/requests/settings | Get the request context of browser-based settings flows
*PublicApi* | [**get_self_service_error**](docs/PublicApi.md#get_self_service_error) | **GET** /self-service/errors | Get user-facing self-service errors
*PublicApi* | [**get_self_service_verification_request**](docs/PublicApi.md#get_self_service_verification_request) | **GET** /self-service/browser/flows/requests/verification | Get the request context of browser-based verification flows
*PublicApi* | [**initialize_self_service_browser_login_flow**](docs/PublicApi.md#initialize_self_service_browser_login_flow) | **GET** /self-service/browser/flows/login | Initialize browser-based login user flow
*PublicApi* | [**initialize_self_service_browser_logout_flow**](docs/PublicApi.md#initialize_self_service_browser_logout_flow) | **GET** /self-service/browser/flows/logout | Initialize Browser-Based Logout User Flow
*PublicApi* | [**initialize_self_service_browser_registration_flow**](docs/PublicApi.md#initialize_self_service_browser_registration_flow) | **GET** /self-service/browser/flows/registration | Initialize browser-based registration user flow
*PublicApi* | [**initialize_self_service_browser_verification_flow**](docs/PublicApi.md#initialize_self_service_browser_verification_flow) | **GET** /self-service/browser/flows/verification/init/{via} | Initialize browser-based verification flow
*PublicApi* | [**initialize_self_service_settings_flow**](docs/PublicApi.md#initialize_self_service_settings_flow) | **GET** /self-service/browser/flows/settings | Initialize browser-based settings flow
*PublicApi* | [**self_service_browser_verify**](docs/PublicApi.md#self_service_browser_verify) | **GET** /self-service/browser/flows/verification/{via}/confirm/{code} | Complete the browser-based verification flows
*PublicApi* | [**whoami**](docs/PublicApi.md#whoami) | **GET** /sessions/whoami | Check who the current HTTP session belongs to
*VersionApi* | [**get_version**](docs/VersionApi.md#get_version) | **GET** /version | Get service version


## Documentation For Models

 - [CompleteSelfServiceBrowserSettingsStrategyProfileFlowPayload](docs/CompleteSelfServiceBrowserSettingsStrategyProfileFlowPayload.md)
 - [Error](docs/Error.md)
 - [ErrorContainer](docs/ErrorContainer.md)
 - [Form](docs/Form.md)
 - [FormField](docs/FormField.md)
 - [GenericError](docs/GenericError.md)
 - [GenericErrorPayload](docs/GenericErrorPayload.md)
 - [HealthNotReadyStatus](docs/HealthNotReadyStatus.md)
 - [HealthStatus](docs/HealthStatus.md)
 - [Identity](docs/Identity.md)
 - [LoginRequest](docs/LoginRequest.md)
 - [LoginRequestMethod](docs/LoginRequestMethod.md)
 - [LoginRequestMethodConfig](docs/LoginRequestMethodConfig.md)
 - [RegistrationRequest](docs/RegistrationRequest.md)
 - [RegistrationRequestMethod](docs/RegistrationRequestMethod.md)
 - [RegistrationRequestMethodConfig](docs/RegistrationRequestMethodConfig.md)
 - [RequestMethodConfig](docs/RequestMethodConfig.md)
 - [Session](docs/Session.md)
 - [SettingsRequest](docs/SettingsRequest.md)
 - [SettingsRequestMethod](docs/SettingsRequestMethod.md)
 - [VerifiableAddress](docs/VerifiableAddress.md)
 - [VerificationRequest](docs/VerificationRequest.md)
 - [Version](docs/Version.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author




